package com.nationrel.modules.project.controller;

import java.util.Arrays;

import com.nationrel.modules.project.entity.PmProject;
import com.nationrel.modules.project.service.IProjectService;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import org.jeecg.common.api.IPageExtField;
import org.jeecg.common.api.PageExtField;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.config.i18n.MessageUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: t_pm_project
 * @Author: nationrel
 * @Date: 2024-10-18
 * @Version: V1.0
 */
@Tag(name="t_pm_project")
@RestController
@RequestMapping("/project/pmProject")
@Slf4j
public class PmProjectController extends JeecgController<PmProject, IProjectService> {
	@Autowired
	private IProjectService pmProjectService;

	/**
	 * 分页列表查询
	 *
	 * @param pmProject
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "t_pm_project-分页列表查询")
	@Operation(summary="t_pm_project-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPageExtField<PmProject>> queryPageList(PmProject pmProject,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<PmProject> queryWrapper = QueryGenerator.initQueryWrapper(pmProject, req.getParameterMap());
		IPageExtField<PmProject> page = new PageExtField<>(PmProject.class, pageNo, pageSize);
		IPageExtField<PmProject> pageList = pmProjectService.page(page, queryWrapper);
		return Result.OK(pageList);
	}

	/**
	 *   添加
	 *
	 * @param pmProject
	 * @return
	 */
	@AutoLog(value = "t_pm_project-添加")
	@Operation(summary="t_pm_project-添加")
	@RequiresPermissions("pmproject:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody PmProject pmProject) {
		pmProjectService.saveProject(pmProject);
		return Result.OK(MessageUtils.get("nationrel_add_success"));
	}

	/**
	 *  编辑
	 *
	 * @param pmProject
	 * @return
	 */
	@AutoLog(value = "t_pm_project-编辑")
	@Operation(summary="t_pm_project-编辑")
	@RequiresPermissions("pmproject:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody PmProject pmProject) {
		pmProjectService.updateById(pmProject);
		return Result.OK(MessageUtils.get("nationrel_edit_success"));
	}

	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "t_pm_project-通过id删除")
	@Operation(summary="t_pm_project-通过id删除")
	@RequiresPermissions("pmproject:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		pmProjectService.removeById(id);
		return Result.OK(MessageUtils.get("nationrel_delete_success"));
	}

	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "t_pm_project-批量删除")
	@Operation(summary="t_pm_project-批量删除")
	@RequiresPermissions("pmproject:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.pmProjectService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK(MessageUtils.get("nationrel_delete_batch_success"));
	}

	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "t_pm_project-通过id查询")
	@Operation(summary="t_pm_project-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<PmProject> queryById(@RequestParam(name="id",required=true) String id) {
		PmProject pmProject = pmProjectService.getById(id);
		if(pmProject==null) {
			return Result.error(MessageUtils.get("nationrel_no_found_data"));
		}
		return Result.OK(pmProject);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param pmProject
    */
    @RequiresPermissions("pmproject:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, PmProject pmProject) {
        return super.exportXls(request, pmProject, PmProject.class, "t_pm_project");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("pmproject:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, PmProject.class);
    }
}
