package com.nationrel.modules.project.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.nationrel.modules.project.dto.PmTaskInfoDto;
import com.nationrel.modules.project.jar.entity.PmTask;
import com.nationrel.modules.project.req.PmProjectEditReq;
import com.nationrel.modules.project.req.PmTaskEditReq;
import com.nationrel.modules.project.req.PmTgEditReq;
import jakarta.servlet.http.HttpServletRequest;
import org.jeecg.common.api.vo.Result;
import com.nationrel.modules.project.entity.PmTaskInfo;
import com.nationrel.modules.project.service.IPmTaskInfoService;

import lombok.extern.slf4j.Slf4j;

import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.config.i18n.MessageUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: t_pm_tg
 * @Author: nationrel
 * @Date: 2024-10-23
 * @Version: V1.0
 */
@Tag(name="t_pm_tg")
@RestController
@RequestMapping("/project/pmtask")
@Slf4j
public class PmTaskInfoController extends JeecgController<PmTaskInfo, IPmTaskInfoService> {
	@Autowired
	private IPmTaskInfoService tgInfoService;

	/**
	 * 分页列表查询
	 *
	 * @param pmTaskInfo
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "t_pm_tg-分页列表查询")
	@Operation(summary="t_pm_tg-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<PmTaskInfoDto>> queryPageList(PmTaskInfo pmTaskInfo,
														   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
														   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
														   HttpServletRequest req) {
		Page<PmTaskInfoDto> page = new Page<>(pageNo, pageSize);
		IPage<PmTaskInfoDto> pageList = tgInfoService.selectPmTaskInfoPage(page, pmTaskInfo.getProjectId());
		return Result.OK(pageList);
	}

	/**
	 *   添加
	 *
	 * @param pmTaskInfo
	 * @return
	 */
	@AutoLog(value = "t_pm_tg-添加")
	@Operation(summary="t_pm_tg-添加")
	@RequiresPermissions("project:t_pm_tg:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody PmTaskInfo pmTaskInfo) {
		tgInfoService.save(pmTaskInfo);
		return Result.OK(MessageUtils.get("nationrel_add_success"));
	}

	/**
	 *  编辑
	 *
	 * @param pmTaskInfo
	 * @return
	 */
	@AutoLog(value = "t_pm_tg-编辑")
	@Operation(summary="t_pm_tg-编辑")
	@RequiresPermissions("project:t_pm_tg:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody PmTaskInfo pmTaskInfo) {
		tgInfoService.updateById(pmTaskInfo);
		return Result.OK(MessageUtils.get("nationrel_edit_success"));
	}

	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "t_pm_tg-通过id删除")
	@Operation(summary="t_pm_tg-通过id删除")
	@RequiresPermissions("project:t_pm_tg:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		tgInfoService.removeById(id);
		return Result.OK(MessageUtils.get("nationrel_delete_success"));
	}

	 @AutoLog(value = "编辑")
	 @Operation(summary="编辑Tg")
	 @RequestMapping(value = "/editTg", method = {RequestMethod.PUT,RequestMethod.POST})
	 public Result<String> editTg(@RequestBody PmTgEditReq pmtgEditReq) {
		 tgInfoService.updateTgInfo(pmtgEditReq);
		 return Result.OK(MessageUtils.get("nationrel_edit_success"));
	 }

	 @AutoLog(value = "编辑")
	 @Operation(summary="编辑Task")
	 @RequestMapping(value = "/editTask", method = {RequestMethod.PUT,RequestMethod.POST})
	 public Result<String> editTask(@RequestBody PmTaskEditReq pmTask) {
		 tgInfoService.updateTaskInfo(pmTask);
		 return Result.OK(MessageUtils.get("nationrel_edit_success"));
	 }

	  @AutoLog(value = "编辑")
	 @Operation(summary="编辑Task")
	 @RequestMapping(value = "/editProject", method = {RequestMethod.PUT,RequestMethod.POST})
	 public Result<String> editProject(@RequestBody PmProjectEditReq pmProjectEditReq) throws Exception {
		 tgInfoService.updateProjectInfo(pmProjectEditReq);
		 return Result.OK(MessageUtils.get("nationrel_edit_success"));
	 }


}
