package com.nationrel.modules.project.controller;

import com.nationrel.modules.project.jar.dto.input.Rb0300101DeleteInput;
import com.nationrel.modules.project.jar.dto.input.Rb0300101InitInput;
import com.nationrel.modules.project.jar.dto.input.Rb0300101SearchInput;
import com.nationrel.modules.project.jar.dto.output.Rb0300101InitOutput;
import com.nationrel.modules.project.jar.dto.output.Rb0300101SearchOutput;
import com.nationrel.modules.project.jar.service.PmProjectService;
import com.nationrel.modules.project.jar.service.Rb0300101InitService;
import com.nationrel.modules.project.jar.service.Rb0300101SearchService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

/**
 * @Description 项目列表
 * @Author nijun
 * @Date 2024/10/11 13:06
 * @Version 1.0
 */
@Tag(name = "项目列表")
@RestController
@RequestMapping("/project/rb0300101")
@Slf4j
public class Rb0300101Controller {

    @Autowired
    private PmProjectService pmProjectService;
    @Autowired
    private Rb0300101InitService rb0300101InitService;
    @Autowired
    private Rb0300101SearchService rb0300101SearchService;

    @AutoLog(value = "删除")
    @Operation(summary="删除")
    @RequestMapping(value = "/delete", method = {RequestMethod.PUT,RequestMethod.POST})
    public Result<?> delete(Rb0300101DeleteInput input) {
        pmProjectService.deleteWholeProject(input.getProjectId());
        return Result.ok();
    }

    @AutoLog(value = "项目列表初始化")
    @Operation(summary="项目列表初始化")
    @RequestMapping(value = "/init", method = {RequestMethod.PUT,RequestMethod.POST})
    public Result<?> init(Rb0300101InitInput input) {
        Rb0300101InitOutput output = new Rb0300101InitOutput();
        try {
            rb0300101InitService.perform(input, output);
        } catch (Exception e) {
            return Result.error(e.getMessage());
        }
        return Result.ok(output);
    }

    @AutoLog(value = "项目列表搜索")
    @Operation(summary="项目列表搜索")
    @RequestMapping(value = "/search", method = {RequestMethod.PUT,RequestMethod.POST})
    public Result<?> search(Rb0300101SearchInput input) {
        Rb0300101SearchOutput output = new Rb0300101SearchOutput();
        try {
            rb0300101SearchService.perform(input, output);
        } catch (Exception e) {
            return Result.error(e.getMessage());
        }
        return Result.ok(output);
    }
}
