package com.nationrel.modules.project.controller;

import com.nationrel.modules.project.jar.dto.input.Rb0300230DeleteInput;
import com.nationrel.modules.project.jar.dto.input.Rb0300230InitInput;
import com.nationrel.modules.project.jar.dto.input.Rb0300230SaveInput;
import com.nationrel.modules.project.jar.dto.output.Rb0300230DeleteOutput;
import com.nationrel.modules.project.jar.dto.output.Rb0300230InitOutput;
import com.nationrel.modules.project.jar.dto.output.Rb0300230SaveOutput;
import com.nationrel.modules.project.jar.service.Rb0300230DeleteService;
import com.nationrel.modules.project.jar.service.Rb0300230InitService;
import com.nationrel.modules.project.jar.service.Rb0300230SaveService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

/**
 * @Description TG检查项删除
 * @Author nijun
 * @Date 2024/10/18 11:56
 * @Version 1.0
 */
@Tag(name = "TG检查项删除")
@RestController
@RequestMapping("/project/rb0300230")
@Slf4j
public class Rb0300230Controller {
    @Autowired
    private Rb0300230DeleteService rb0300230DeleteService;
    @Autowired
    private Rb0300230InitService rb0300230InitService;
    @Autowired
    private Rb0300230SaveService rb0300230SaveService;

    @AutoLog(value = "任务列表初始化的业务方法")
    @Operation(summary="任务列表初始化的业务方法")
    @RequestMapping(value = "/init", method = {RequestMethod.GET,RequestMethod.POST})
    public Result<?> init(Rb0300230InitInput input) {
        Rb0300230InitOutput output = new Rb0300230InitOutput();
        try {
            rb0300230InitService.perform(input, output);
        } catch (Exception e) {
            return Result.error(e.getMessage());
        }
        return Result.ok(output);
    }

    @AutoLog(value = "任务删除的业务方法")
    @Operation(summary="任务删除的业务方法")
    @RequestMapping(value = "/delete", method = {RequestMethod.PUT,RequestMethod.POST})
    public Result<?> delete(Rb0300230DeleteInput input) {
        Rb0300230DeleteOutput output = new Rb0300230DeleteOutput();
        try {
            rb0300230DeleteService.perform(input, output);
        } catch (Exception e) {
            return Result.error(e.getMessage());
        }
        return Result.ok();
    }

    @AutoLog(value = "项目检查列表保存业务方法")
    @Operation(summary="项目检查列表保存业务方法")
    @RequestMapping(value = "/save", method = {RequestMethod.PUT,RequestMethod.POST})
    public Result<?> save(@RequestBody Rb0300230SaveInput input) {
        Rb0300230SaveOutput output = new Rb0300230SaveOutput();
        try {
            rb0300230SaveService.perform(input, output);
        } catch (Exception e) {
            return Result.error(e.getMessage());
        }
        return Result.ok();
    }
}
