package com.nationrel.modules.project.controller;

import com.nationrel.modules.project.jar.dto.input.Rb0300141AddMemberInput;
import com.nationrel.modules.project.jar.dto.input.Rb0300241AddMemberInput;
import com.nationrel.modules.project.jar.dto.input.Rb0300241InitInput;
import com.nationrel.modules.project.jar.dto.input.Rb0300241SearchInput;
import com.nationrel.modules.project.jar.dto.output.Rb0300141AddMemberOutput;
import com.nationrel.modules.project.jar.dto.output.Rb0300241AddMemberOutput;
import com.nationrel.modules.project.jar.dto.output.Rb0300241InitOutput;
import com.nationrel.modules.project.jar.dto.output.Rb0300241SearchOutput;
import com.nationrel.modules.project.jar.service.Rb0300241AddMemberService;
import com.nationrel.modules.project.jar.service.Rb0300241InitService;
import com.nationrel.modules.project.jar.service.Rb0300241SearchService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * @Description TG增加成员选择
 * @Author nijun
 * @Date 2024/10/18 11:56
 * @Version 1.0
 */
@Tag(name = "TG增加成员选择")
@RestController
@RequestMapping("/project/rb0300241")
@Slf4j
public class Rb0300241Controller {
    @Autowired
    private Rb0300241AddMemberService rb0300241AddMemberService;
    @Autowired
    private Rb0300241InitService rb0300241InitService;
    @Autowired
    private Rb0300241SearchService rb0300241SearchService;

    @AutoLog(value = "项目成员列表初始化的业务方法")
    @Operation(summary="项目成员列表初始化的业务方法")
    @RequestMapping(value = "/init", method = {RequestMethod.GET,RequestMethod.POST})
    public Result<?> init(Rb0300241InitInput input) {
        List<Map<String, String>> perform = new ArrayList<>();
        try {
            perform = rb0300241InitService.perform(input);
        } catch (Exception e) {
            return Result.error(e.getMessage());
        }
        return Result.ok(perform);
    }

    @AutoLog(value = "成员添加的业务方法")
    @Operation(summary="成员添加的业务方法")
    @RequestMapping(value = "/delete", method = {RequestMethod.PUT,RequestMethod.POST})
    public Result<?> delete(Rb0300241AddMemberInput input) {
        Rb0300241AddMemberOutput output = new Rb0300241AddMemberOutput();
        try {
            rb0300241AddMemberService.perform(input, output);
        } catch (Exception e) {
            return Result.error(e.getMessage());
        }
        return Result.ok();
    }

    @AutoLog(value = "项目成员列表查询的业务方法")
    @Operation(summary="项目成员列表查询的业务方法")
    @RequestMapping(value = "/search", method = {RequestMethod.GET,RequestMethod.POST})
    public Result<?> search(Rb0300241SearchInput input) {
        Rb0300241SearchOutput output = new Rb0300241SearchOutput();
        try {
            rb0300241SearchService.perform(input, output);
        } catch (Exception e) {
            return Result.error(e.getMessage());
        }
        return Result.ok();
    }

    @AutoLog(value = "项目成员选择页面添加成员业务方法")
    @Operation(summary="项目成员选择页面添加成员业务方法")
    @RequestMapping(value = "/addMember", method = {RequestMethod.PUT,RequestMethod.POST})
    public Result<?> addMember(@RequestBody Rb0300241AddMemberInput input) {
        Rb0300241AddMemberOutput output = new Rb0300241AddMemberOutput();
        try {
            rb0300241AddMemberService.perform(input, output);
        } catch (Exception e) {
            return Result.error(e.getMessage());
        }
        return Result.ok();
    }
}
