// Copyright(c) 2013 ReliaBench. All rights reserved.
package com.nationrel.modules.project.jar.mapper;

import com.nationrel.modules.project.jar.rb_common.common.dto.Pagination;
import com.nationrel.modules.project.jar.rb_common.common.mapper.BaseMapper;
import com.nationrel.modules.project.jar.entity.BsDocument;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

/**
 * @ClassName BsDocumentMapper
 * @Description 文档管理表 Mapper接口
 * @Author
 * @CreateDate 2013-11-6
 * @version V1.0
 */
public interface BsDocumentMapper extends BaseMapper<BsDocument, String> {

    /**
     * @Title: countDocumentByCondition
     * @Description: 通过搜索条件获取文档查询列表总数
     * @param argMap 条件
     * @return int
     */
    int countDocumentByCondition(@Param("argMap") Map<String, Object> argMap);

    /**
     * @Title: selectDocumentByCondition
     * @Description: 通过搜索条件获取文档列表
     * @param pagination 分页
     * @param argMap 条件
     * @return List<Map>
     */
    @SuppressWarnings("rawtypes")
    List<Map> selectDocumentByCondition(@Param("pagination") Pagination pagination, @Param("argMap") Map<String, Object> argMap);

    /**
     * @Title: selectByDocumentId
     * @Description:通过主键获取相应的实体
     * @param documentId
     * @return Map
     */
    @SuppressWarnings("rawtypes")
    Map selectByDocumentId(@Param("documentId") String documentId);

    /**
     * @Title: selectByVerionNoAndSeries
     * @Description: 通过原始版本号、版本分组号获取文档版本历史
     * @param versionNo
     * @param versionSeries
     * @return List<BsDocument>
     */
    @SuppressWarnings("rawtypes")
    List<Map> selectByVerionNoAndSeries(
            @Param("versionCode") Integer versionCode,
            @Param("versionSeries") String versionSeries);

    /**
     * @Title: updateByPrimaryKeySelective
     * @Description: 更新
     * @param versionNo
     * @param versionSeries
     * @return List<BsDocument>
     */
    void updateByPrimaryKeySelective(BsDocument bsDocument);

    /**
     * @Title: selectUserAndTime
     * @Description: 选择插入用户，插入时间，更新用户，更新时间
     * @param versionNo
     * @param versionSeries
     * @return List<BsDocument>
     */
    @SuppressWarnings("rawtypes")
    Map selectUserAndTime(@Param("moduleId") String moduleId,
            @Param("businessId") String businessId);

    /**
     * @Title: searchDocListByProjectId
     * @Description: 根据项目Id获取项目下文档列表
     * @param projectId
     * @return List<Map<String, Object>>
     */
    List<Map<String , Object>> searchDocListByProjectId(@Param("projectId") String projectId);

    /**
     * @Title: searchDocListByProjectId
     * @Description: 根据TG Id获取项目下文档列表
     * @param projectId
     * @return List<Map<String, Object>>
     */
    List<Map<String , Object>> searchDocListByTGId(@Param("tgId") String tgId);

    /**
     * @Title: searchDocListByProjectId
     * @Description: 根据步骤Id获取项目下文档列表
     * @param projectId
     * @return List<Map<String, Object>>
     */
    List<Map<String , Object>> searchDocListByStepId(@Param("stepId") String stepId);
}
