// Copyright(c) 2013 ReliaBench. All rights reserved.
package com.nationrel.modules.project.jar.service.impl;

import com.nationrel.modules.project.jar.dto.input.Rb0101403InitInput;
import com.nationrel.modules.project.jar.dto.output.Rb0101403InitOutput;
import com.nationrel.modules.project.jar.entity.BsAttachment;
import com.nationrel.modules.project.jar.entity.BsDocumentType;
import com.nationrel.modules.project.jar.mapper.BsAttachmentMapper;
import com.nationrel.modules.project.jar.mapper.BsDocumentMapper;
import com.nationrel.modules.project.jar.mapper.BsDocumentTypeMapper;
import com.nationrel.modules.project.jar.rb_common.bizcommon.constant.BizModuleCode;
import com.nationrel.modules.project.jar.rb_common.common.constant.Constants;
import com.nationrel.modules.project.jar.rb_platform.mapper.SysStateConfigMapper;
import com.nationrel.modules.project.jar.service.Rb0101403InitService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

/**
 * @ClassName Rb0101403InitServiceImpl
 * @Description 文档查看初始化服务实现
 * @Author 赵安会
 * @CreateDate 2013-11-06
 * @Version V1.0
 */
@Service
public class Rb0101403InitServiceImpl implements Rb0101403InitService {

    @Autowired
    private BsDocumentMapper bsDocumentMapper;
    @Autowired
    private BsAttachmentMapper bsAttachmentMapper;
    @Autowired
    private BsDocumentTypeMapper bsDocumentTypeMapper;
    @Autowired
    private SysStateConfigMapper sysStateConfigMapper;

    /**
     * @Title: perform
     * @Description:操作
     * @param userInfo 当前登录的用户
     * @param input 输入
     * @param output 输出
     * @return 操作结果
     * @throws Exception 异常
     */
    @Override
    public String perform(Rb0101403InitInput input, Rb0101403InitOutput output) throws Exception {

        // 获取相关附件的列表信息
        List<BsAttachment> list = bsAttachmentMapper.selectByDocumentId(input.getDocumentId());

        // 获取文档信息
        @SuppressWarnings("rawtypes")
        Map bsDocument = bsDocumentMapper.selectByDocumentId(input.getDocumentId());

        // 设置文档类型父级名称
        setPartentTypeName(bsDocument);

        // 设置查询结果
        output.setList(list);

        // 设置输出信息
        if (bsDocument != null) {
            output.setBsDocument(bsDocument);
        }

        //返回业务类型id
        output.setModuleId(BizModuleCode.MODULE_ID_DOCUMENT);
        output.setDocumentId(input.getDocumentId());

        // 返回成功
        return Constants.SERVICE_SUCCESS;
    }

   /**
    * @Title: setPartentTypeName
    * @param bsDocument 文档
    * @Description: 设置文档类型父级名称
    */
    @SuppressWarnings({ "rawtypes", "unchecked" })
    public void setPartentTypeName(Map bsDocument) {
        if (bsDocument != null) {
            String pd = "PARENT_DOC_ID";
            Object oparentDocId = bsDocument.get(pd);
            String parentDocId = "";
            if (oparentDocId != null) {
                parentDocId = bsDocument.get(pd).toString();
            }
           // 如果存在父级就查询父级名称
            if (StringUtils.isNotEmpty(parentDocId)) {
                BsDocumentType bsType = bsDocumentTypeMapper.selectByPrimaryKey(parentDocId);
                if (bsType != null) {
                   // 设置父级名称
                    bsDocument.put(pd, bsType.getName());
                }
            }
        }
    }

}
