package com.nationrel.modules.project.jar.service.impl;

import com.nationrel.modules.project.jar.dto.input.Rb0300112EditInput;
import com.nationrel.modules.project.jar.dto.output.Rb0300112EditOutput;
import com.nationrel.modules.project.jar.entity.PmProject;
import com.nationrel.modules.project.jar.rb_common.common.constant.Constants;
import com.nationrel.modules.project.jar.rb_common.common.constant.MessageId;
import com.nationrel.modules.project.jar.rb_common.common.constant.SessionKeys;
import com.nationrel.modules.project.jar.rb_common.exception.OptimisticLockException;
import com.nationrel.modules.project.jar.util.DateUtils;
import com.nationrel.modules.project.jar.util.SessionUtil;
import com.nationrel.modules.project.jar.mapper.PmProjectMapper;
import com.nationrel.modules.project.jar.service.PmProjectService;
import com.nationrel.modules.project.jar.service.Rb0300112EditService;
import org.apache.commons.lang3.ObjectUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.shiro.SecurityUtils;
import org.jeecg.common.system.vo.LoginUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;

/**
 * @version V1.0
 * @ClassName Rb0300112EditServiceImpl
 * @Description 项目对象保存的业务实现类
 * @Author andy
 * @CreateDate 2013-12-10
 */
@Service
public class Rb0300112EditServiceImpl implements Rb0300112EditService {

    @Autowired
    private PmProjectMapper pmProjectMapper;
    @Autowired
    private PmProjectService pmProjectService;

    /**

     * @param input    输入参数
     * @param output   输出参数
     * @return String 返回结果
     * @Title perform
     * @Description 创建项目对象的业务方法
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public String perform(Rb0300112EditInput input, Rb0300112EditOutput output) throws Exception {
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        // 获取projectId
        String projectId = input.getProjectId();

        // 设置项目对象的基本信息
        PmProject pmProject = pmProjectMapper.selectByPrimaryKey(projectId);
        if (!ObjectUtils.isEmpty(pmProject) && !pmProject.getVersionNo().equals(input.getVersionNo())) {
            throw new OptimisticLockException(MessageId.W009801);
        }
        Date dtPlanStartTime = DateUtils.convertDate(input.getPlanStartTime());
        Date dtPlanEndTime = DateUtils.convertDate(input.getPlanEndTime());

        // 时间有变动，时间整合性检查
        if ((ObjectUtils.isNotEmpty(dtPlanStartTime) && ObjectUtils.isNotEmpty(dtPlanEndTime)) && (DateUtils.isNotDateEquals(pmProject.getPlanStartTime(), dtPlanStartTime) ||
                DateUtils.isNotDateEquals(pmProject.getPlanEndTime(), dtPlanEndTime))) {
            pmProjectService.checkContainTimeOfTG(dtPlanStartTime, dtPlanEndTime, projectId);
        }

        // 页面输入值再设定
        if (ObjectUtils.isNotEmpty(input.getProjectCode())) {
            pmProject.setProjectCode(input.getProjectCode());
        }
        if (ObjectUtils.isNotEmpty(input.getProjectName())) {
            pmProject.setProjectName(input.getProjectName());
        }
        if (ObjectUtils.isNotEmpty(input.getObjectName())) {
            pmProject.setObjectName(input.getObjectName());
        }
        if (ObjectUtils.isNotEmpty(input.getProjectCode())) {
            pmProject.setProjectCode(input.getProjectCode());
        }
        if (ObjectUtils.isNotEmpty(input.getProjectType())) {
            pmProject.setProjectType(String.valueOf(input.getProjectType()));
        }
        if (ObjectUtils.isNotEmpty(input.getApplication())) {
            pmProject.setProjectApp(String.valueOf(input.getApplication()));
        }
        if (ObjectUtils.isNotEmpty(dtPlanStartTime)) {
            pmProject.setPlanStartTime(dtPlanStartTime);
        }
        if (ObjectUtils.isNotEmpty(dtPlanEndTime)) {
            pmProject.setPlanEndTime(dtPlanEndTime);
        }

        if (ObjectUtils.isNotEmpty(input.getDescription())) {
            pmProject.setDescription(input.getDescription().trim());
        }

        // 设置系统信息到项目对象
        pmProject.setUpdatePgmId(StringUtils.EMPTY);
        pmProject.setUpdateUserId(sysUser.getUsername());
        pmProject.setUpdateTime(new Date());

        // 保存项目对象到数据库
        pmProjectMapper.updateByPrimaryKey(pmProject);

        // 返回结果
        return Constants.SERVICE_SUCCESS;
    }

}
