package com.nationrel.modules.project.jar.service.impl;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.nationrel.modules.project.jar.dto.input.Rb0300140InitInput;
import com.nationrel.modules.project.jar.dto.output.Rb0300140InitOutput;
import com.nationrel.modules.project.jar.rb_common.common.constant.Constants;
import com.nationrel.modules.project.jar.rb_common.common.constant.PmMapKeySet;
import com.nationrel.modules.project.jar.rb_common.common.constant.ReliaFlowConstants;
import com.nationrel.modules.project.jar.rb_common.common.constant.SessionKeys;
import com.nationrel.modules.project.jar.util.SessionUtil;
import com.nationrel.modules.project.jar.util.StringUtil;
import com.nationrel.modules.project.jar.mapper.PmProjectRoleMapper;
import com.nationrel.modules.project.jar.mapper.PmProjectStaffMapper;
import com.nationrel.modules.project.jar.service.AuthorityCtrlService;
import com.nationrel.modules.project.jar.service.Rb0300140InitService;
import org.apache.commons.lang3.StringUtils;
import org.apache.shiro.SecurityUtils;
import org.checkerframework.checker.units.qual.C;
import org.jeecg.common.api.CommonAPI;
import org.jeecg.common.system.vo.LoginUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.HashMap;
import java.util.List;
import java.util.Map;


/**
 * @version V1.0
 * @ClassName Rb0300140InitServiceImpl
 * @Description 项目成员列表页面初始化的业务类
 * @Author andy
 * @CreateDate 2013-12-24
 */
@Service
public class Rb0300140InitServiceImpl implements Rb0300140InitService {

    @Autowired
    private PmProjectStaffMapper pmProjectStaffMapper;
    @Autowired
    private PmProjectRoleMapper pmProjectRoleMapper;
    @Autowired
    private AuthorityCtrlService authorityCtrlService;
    @Autowired
    private CommonAPI commonAPI;

    /**

     * @param input    输入参数
     * @return 操作结果
     * @Title: perform
     * @Description TG列表初始化的业务方法
     */
    @Override
    public Rb0300140InitOutput perform(Rb0300140InitInput input) throws Exception {
        Rb0300140InitOutput output = new Rb0300140InitOutput();
        List<Map<String, Object>> resultList = Lists.newArrayList();
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        // 取得项目标识
        String projectId = input.getProjectId();

        // 取得项目成员列表
        List<Map<String, Object>> pmProjectStaffs = pmProjectStaffMapper.searchProjectMemberListByProjectId(projectId);

        // 控制删除是否可见,符合当前login userId==staffId && 角色是项目经理的成员不可以删除.
        int disableOperateCnt = 0;
        if (!CollectionUtils.isEmpty(pmProjectStaffs)) {
            for (Map<String, Object> pmProjectStaffMap : pmProjectStaffs) {
                Map<String, Object> resultMap = Maps.newHashMap();
                String staffId = StringUtil.parseString(pmProjectStaffMap.get(PmMapKeySet.KEY_R_STAFF_ID));
                String roleId = StringUtil.parseString(pmProjectStaffMap.get(PmMapKeySet.KEY_R_STAFF_ROLEID));
                if ((staffId.equals(sysUser.getUsername()) && roleId.equals(ReliaFlowConstants.PROJECT_MANAGER_ID)) ||
                        roleId.equals(ReliaFlowConstants.PROJECT_OWNER_ID)) {
                    resultMap.put(ReliaFlowConstants.AUTHORITY_MODIFY, ReliaFlowConstants.AUTH_CTRL_VIEW);
                    resultMap.put(ReliaFlowConstants.AUTHORITY_DELETE, ReliaFlowConstants.AUTH_CTRL_VIEW);
                    disableOperateCnt++;
                }

                LoginUser user = commonAPI.getUserByName(staffId);
                resultMap.put("staffId", staffId);
                resultMap.put("roleId", roleId);
                resultMap.put("staffName", user.getRealname());
                resultMap.put("staffRoleName", pmProjectStaffMap.get(PmMapKeySet.KEY_R_STAFF_ROLENAME));
                resultMap.put("startTime", pmProjectStaffMap.get(PmMapKeySet.KEY_R_START_TIME));
                resultMap.put("mobile", user.getPhone());
                resultMap.put("telephone", user.getTelephone());
                resultMap.put("email", user.getEmail());
                resultMap.put("loginId", user.getId());
                resultList.add(resultMap);
            }
        }


        // 页面权限控制
        /*Map<String, String> argMap = new HashMap<String, String>();
        argMap.put(PmMapKeySet.KEY_S_PROJECT_ID, projectId);
        argMap.put(PmMapKeySet.KEY_S_USER_ID, sysUser.getUsername());
        argMap.put(PmMapKeySet.KEY_S_RESOURCE_ID, projectId);
        argMap.put(PmMapKeySet.KEY_S_RESOURCE_TYPE, ReliaFlowConstants.RESOURCE_PROJECT_TYPE);
        argMap.put(PmMapKeySet.KEY_S_CHILD_RESOURCE_TYPE, ReliaFlowConstants.MEMBER_TYPE);*/
/*
        // 取得具体资源的权限
        Map<String, String> authMap = authorityCtrlService.doResourceAuthority(argMap);

        // 统计显示操作按钮的数量
        int ctrOptCount = 0;

        if (StringUtils.isEmpty(authMap.get(ReliaFlowConstants.AUTHORITY_MODIFY))) {
            ctrOptCount++;
        }
        if (StringUtils.isEmpty(authMap.get(ReliaFlowConstants.AUTHORITY_DELETE))) {
            ctrOptCount++;
        }
        if (disableOperateCnt == pmProjectStaffs.size() && ctrOptCount > 0) {
            ctrOptCount = 0;
        }*/

        // 统计显示操作按钮的数量
//        output.setCtrOptCount(ctrOptCount);
//        output.setAuthMap(authMap);
        output.setPmProjectStaffs(resultList);

        // 处理结果
        return output;
    }

}
