package com.nationrel.modules.project.jar.service.impl;

import com.nationrel.modules.project.jar.dto.input.Rb0300232SaveInput;
import com.nationrel.modules.project.jar.dto.output.Rb0300232SaveOutput;
import com.nationrel.modules.project.jar.entity.PmTgCheck;
import com.nationrel.modules.project.jar.rb_common.common.constant.Constants;
import com.nationrel.modules.project.jar.rb_common.common.constant.MessageId;
import com.nationrel.modules.project.jar.rb_common.common.constant.SessionKeys;
import com.nationrel.modules.project.jar.rb_common.exception.OptimisticLockException;
import com.nationrel.modules.project.jar.util.SessionUtil;
import com.nationrel.modules.project.jar.mapper.PmTgCheckMapper;
import com.nationrel.modules.project.jar.service.PmTgService;
import com.nationrel.modules.project.jar.service.Rb0300232SaveService;
import org.apache.commons.lang3.StringUtils;
import org.apache.shiro.SecurityUtils;
import org.jeecg.common.system.vo.LoginUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * @version V1.0
 * @ClassName Rb0300332SaveServiceImpl
 * @Description TG检查项保存业务类
 * @Author ted.liu
 * @CreateDate 2013-12-19
 */
@Service
public class Rb0300232SaveServiceImpl implements Rb0300232SaveService {

    @Autowired
    private PmTgCheckMapper pmTgCheckMapper;
    @Autowired
    private PmTgService pmTgService;

    /**

     * @param input    输入参数
     * @param output   输出参数
     * @return 操作结果
     * @Title: perform
     * @Description TG检查项保存业务方法
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public String perform(Rb0300232SaveInput input, Rb0300232SaveOutput output) throws Exception {
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        // 取得TG标识
        String tgId = input.getTgId();

        // 取得TG标识
        Integer tgCheckId = input.getTgCheckId();

        // 1.检查TG是否存在
        pmTgService.checkTgExist(tgId);

        // 2.检查check item 是否存在
        PmTgCheck entity = pmTgCheckMapper.selectByPrimaryKey(tgCheckId, tgId);
        if (entity == null) {
            throw new OptimisticLockException(MessageId.W009803);
        } else {

            // 获取session中TG version number
            Integer versionNumber = input.getVer();

            // 3.检查version number 是否一致
            if (!entity.getVersionNo().equals(versionNumber)) {
                throw new OptimisticLockException(MessageId.W009801);
            }
        }

        // 基本信息
        entity.setObject(input.getObject());
        entity.setContent(input.getContent());
        entity.setDescription(input.getDescription());

        // 系统信息
        entity.setUpdateUserId(sysUser.getUsername());
        entity.setUpdatePgmId(StringUtils.EMPTY);

        // 检查项保存数据库
        pmTgCheckMapper.updateByPrimaryKey(entity);

        // 处理结果
        return Constants.SERVICE_SUCCESS;
    }

}
