package com.nationrel.modules.project.jar.service.impl;

import com.nationrel.modules.project.jar.dto.input.Rb0300241AddMemberInput;
import com.nationrel.modules.project.jar.dto.output.Rb0300241AddMemberOutput;
import com.nationrel.modules.project.jar.entity.PmTaskStaff;
import com.nationrel.modules.project.jar.entity.PmTgStaff;
import com.nationrel.modules.project.jar.rb_common.common.constant.Constants;
import com.nationrel.modules.project.jar.rb_common.common.constant.PmMapKeySet;
import com.nationrel.modules.project.jar.rb_common.common.constant.ReliaFlowConstants;
import com.nationrel.modules.project.jar.rb_common.common.constant.SessionKeys;
import com.nationrel.modules.project.jar.util.SessionUtil;
import com.nationrel.modules.project.jar.util.StringUtil;
import com.nationrel.modules.project.jar.mapper.PmTaskStaffMapper;
import com.nationrel.modules.project.jar.mapper.PmTgStaffMapper;
import com.nationrel.modules.project.jar.service.PmTgService;
import com.nationrel.modules.project.jar.service.Rb0300241AddMemberService;
import org.apache.commons.lang3.StringUtils;
import org.apache.shiro.SecurityUtils;
import org.jeecg.common.system.vo.LoginUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;

/**
 * @version V1.0
 * @ClassName Rb0300241AddMemberServiceImpl
 * @Description TG增加成员业务类
 * @Author andy
 * @CreateDate 2013-12-24
 */
@Service
public class Rb0300241AddMemberServiceImpl implements Rb0300241AddMemberService {

    @Autowired
    private PmTgStaffMapper pmTgStaffMapper;
    @Autowired
    private PmTaskStaffMapper pmTaskStaffMapper;
    @Autowired
    private PmTgService pmTgService;

    /**

     * @param input    输入参数
     * @param output   输出参数
     * @return 操作结果
     * @Title: perform
     * @Description 项目内部增加成员业务方法
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public String perform(Rb0300241AddMemberInput input, Rb0300241AddMemberOutput output) throws Exception {
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        int selectType = input.getSelectType();
        String result = Constants.SERVICE_FAIL;

        Map<String, String> argMap = new HashMap<String, String>();
        Set<String> sets = new HashSet<String>();

        switch (selectType) {
            case 1:
                String tgId = input.getTgId();

                // 检查TG是否存在
                pmTgService.checkTgExist(tgId);

                argMap.put(PmMapKeySet.KEY_S_TG_ID, tgId);
                List<Map<String, String>> existStaffs = pmTgStaffMapper.selectExistStaff(argMap);
                for (Map<String, String> obj : existStaffs) {
                    sets.add(StringUtil.parseString(obj.get(PmMapKeySet.KEY_R_STAFF_ID)));
                }
                // TG成员添加
                if (input.getStaffIds() != null) {
                    input.getStaffIds();
                    for (String staffId : input.getStaffIds()) {
                        boolean exist = sets.add(staffId);
                        if (exist) {
                            PmTgStaff pmTgStaff = new PmTgStaff();
                            // 基本信息
                            pmTgStaff.setTgId(tgId);
                            pmTgStaff.setStaffId(staffId);
                            pmTgStaff.setProjectRoleId(ReliaFlowConstants.PROJECT_ROLE_TG_MEMBER_ID);
                            pmTgStaff.setIsApply(ReliaFlowConstants.IS_APPLY_YES);
                            pmTgStaff.setStartTime(new Date(System.currentTimeMillis()));
                            // 系统信息
                            pmTgStaff.setInsertUserId(sysUser.getUsername());
                            pmTgStaff.setInsertPgmId(StringUtils.EMPTY);
                            pmTgStaffMapper.insert(pmTgStaff);
                        }
                    }
                }
                result = ReliaFlowConstants.TG_STAFF_LIST;
                break;
            case 2:
                String taskId = input.getTaskId();
                argMap.put(PmMapKeySet.KEY_S_TASK_ID, taskId);
                List<Map<String, String>> existTaskStaffs = pmTaskStaffMapper.selectExistStaff(argMap);
                for (Map<String, String> obj : existTaskStaffs) {
                    sets.add(StringUtil.parseString(obj.get(PmMapKeySet.KEY_R_STAFF_ID)));
                }

                // Task成员添加
                if (input.getStaffIds() != null) {
                    input.getStaffIds();
                    for (String staffId : input.getStaffIds()) {
                        boolean exist = sets.add(staffId);
                        if (exist) {
                            PmTaskStaff pmTgStaff = new PmTaskStaff();
                            // 基本信息
                            pmTgStaff.setTaskId(taskId);
                            pmTgStaff.setStaffId(staffId);
                            pmTgStaff.setProjectRoleId(ReliaFlowConstants.PROJECT_ROLE_TASK_MEMBER_ID);
                            pmTgStaff.setIsApply(ReliaFlowConstants.IS_APPLY_YES);
                            pmTgStaff.setStartTime(new Date(System.currentTimeMillis()));
                            // 系统信息
                            pmTgStaff.setInsertUserId(sysUser.getUsername());
                            pmTgStaff.setInsertPgmId(StringUtils.EMPTY);
                            pmTaskStaffMapper.insert(pmTgStaff);
                        }
                    }
                }
                // Task成员添加
                result = ReliaFlowConstants.TASK_STAFF_LIST;
                break;
            default:
                break;
        }

        // 返回结果
        return result;
    }

}
