package com.nationrel.modules.project.jar.service.impl;

import com.google.common.collect.Maps;
import com.nationrel.modules.project.jar.dto.input.Rb0300241InitInput;
import com.nationrel.modules.project.jar.dto.output.Rb0300241InitOutput;
import com.nationrel.modules.project.jar.entity.PmTaskTree;
import com.nationrel.modules.project.jar.rb_common.common.constant.Constants;
import com.nationrel.modules.project.jar.rb_common.common.constant.PmMapKeySet;
import com.nationrel.modules.project.jar.rb_common.common.constant.ReliaFlowConstants;
import com.nationrel.modules.project.jar.rb_common.common.constant.SessionKeys;
import com.nationrel.modules.project.jar.util.SessionUtil;
import com.nationrel.modules.project.jar.util.StringUtil;
import com.nationrel.modules.project.jar.mapper.PmProjectStaffMapper;
import com.nationrel.modules.project.jar.mapper.PmTaskStaffMapper;
import com.nationrel.modules.project.jar.mapper.PmTaskTreeMapper;
import com.nationrel.modules.project.jar.mapper.PmTgStaffMapper;
import com.nationrel.modules.project.jar.service.PmTaskService;
import com.nationrel.modules.project.jar.service.PmTgService;
import com.nationrel.modules.project.jar.service.Rb0300241InitService;
import org.apache.commons.lang3.ObjectUtils;
import org.apache.commons.lang3.StringUtils;
import org.jeecg.common.api.CommonAPI;
import org.jeecg.common.system.vo.LoginUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @version V1.0
 * @ClassName Rb0300241InitServiceImpl
 * @Description TG添加成员初始化业务类
 * @Author andy
 * @CreateDate 2013-12-24
 */
@Service
public class Rb0300241InitServiceImpl implements Rb0300241InitService {

    @Autowired
    private PmProjectStaffMapper pmProjectStaffMapper;
    @Autowired
    private PmTgStaffMapper pmTgStaffMapper;
    @Autowired
    private PmTaskStaffMapper pmTaskStaffMapper;
    @Autowired
    private PmTgService pmTgService;
    @Autowired
    private PmTaskService pmTaskService;
    @Autowired
    private PmTaskTreeMapper pmTaskTreeMapper;
    @Autowired
    private CommonAPI commonAPI;

    /**

     * @param input    输入参数
     * @param output   输出参数
     * @return 操作结果
     * @Title: perform
     * @Description 项目内部增加成员选择页面页面初始化业务方法
     */
    @Override
    public List<Map<String, String>> perform(Rb0300241InitInput input) throws Exception {

        int selectType = input.getSelectType();
        Map<String, String> argMap = new HashMap<String, String>();
        List<Map<String, String>> result = new ArrayList<>();
        switch (selectType) {
            case 1://TG
                argMap.put(PmMapKeySet.KEY_S_PROJECT_ID, input.getProjectId());
                argMap.put(PmMapKeySet.KEY_S_TG_ID, input.getTgId());
                // 检查TG是否存在
                pmTgService.checkTgExist(input.getTgId());
                List<Map<String, String>> srcStaffs = pmProjectStaffMapper.searchPerson(argMap);
                srcStaffs.forEach(staff -> {
                    LoginUser user = commonAPI.getUserByName(staff.get(PmMapKeySet.KEY_R_STAFF_ID));
                    staff.put("username", user.getUsername());
                    staff.put("realname", user.getRealname());
                    staff.put("sex_dictText", ObjectUtils.isNotEmpty(user.getSex()) ? String.valueOf(user.getSex()) : null);
                    staff.put("phone", user.getPhone());
                    staff.put("email", user.getEmail());
                    staff.put("status_dictText", String.valueOf(user.getStatus()));
                });
                List<Map<String, String>> existStaffs = pmTgStaffMapper.selectExistStaff(argMap);
                result = combineStaff(srcStaffs, existStaffs);
                break;
            case 2://Task
                String tgIdTask = input.getTgId();

                // 检查TG是否存在
                pmTgService.checkTgExist(tgIdTask);

                // 获取当前Task成员信息
                String taskId = input.getTaskId();

                // 检查任务是否存在
                pmTaskService.checkTaskExist(taskId);

                PmTaskTree pmTaskTree = pmTaskTreeMapper.selectByPrimaryKey(taskId);
                argMap.put(PmMapKeySet.KEY_S_TASK_ID, taskId);
                if (ReliaFlowConstants.TASK_FIRST_PARENT_ID.equals(pmTaskTree.getParentTaskId())) {
                    argMap.put(PmMapKeySet.KEY_S_TG_ID, tgIdTask);
                    List<Map<String, String>> srcTaskStaffs = pmTgStaffMapper.searchPerson(argMap);
                    srcTaskStaffs.forEach(staff -> {
                        LoginUser user = commonAPI.getUserByName(staff.get(PmMapKeySet.KEY_R_STAFF_ID));
                        staff.put("username", user.getUsername());
                        staff.put("realname", user.getRealname());
                        staff.put("sex_dictText", ObjectUtils.isNotEmpty(user.getSex()) ? String.valueOf(user.getSex()) : null);
                        staff.put("phone", user.getPhone());
                        staff.put("email", user.getEmail());
                        staff.put("status_dictText", String.valueOf(user.getStatus()));
                    });
                    List<Map<String, String>> existTaskStaffs = pmTaskStaffMapper.selectExistStaff(argMap);
                    result = combineStaff(srcTaskStaffs, existTaskStaffs);
                } else {
                    argMap.put(PmMapKeySet.KEY_S_PARENT_TASK_ID, pmTaskTree.getParentTaskId());
                    List<Map<String, String>> srcTaskStaffs = pmTaskStaffMapper.searchPerson(argMap);
                    srcTaskStaffs.forEach(staff -> {
                        LoginUser user = commonAPI.getUserByName(staff.get(PmMapKeySet.KEY_R_STAFF_ID));
                        staff.put("username", user.getUsername());
                        staff.put("realname", user.getRealname());
                        staff.put("sex_dictText", ObjectUtils.isNotEmpty(user.getSex()) ? String.valueOf(user.getSex()) : null);
                        staff.put("phone", user.getPhone());
                        staff.put("email", user.getEmail());
                        staff.put("status_dictText", String.valueOf(user.getStatus()));
                    });
                    List<Map<String, String>> existTaskStaffs = pmTaskStaffMapper.selectExistStaff(argMap);
                    result = combineStaff(srcTaskStaffs, existTaskStaffs);
                }
                break;
            default:
                break;
        }

        // 返回成功
        return result;
    }

    /**
     * @param srcStaffs
     * @param existStaffs
     * @return List<Map < String, String>>
     * @Title: combineStaff
     * @Description: 编辑可选的成员列表（去除已增加的人员）
     */
    private List<Map<String, String>> combineStaff(List<Map<String, String>> srcStaffs,
                                                   List<Map<String, String>> existStaffs) {
        List<Map<String, String>> retList = new ArrayList<Map<String, String>>();

        // 编辑已增加过的成员
        Map<String, String> existMap = new HashMap<String, String>();
        for (Map<String, String> tmpMap : existStaffs) {
            existMap.put(tmpMap.get(PmMapKeySet.KEY_R_STAFF_ID), tmpMap.get(PmMapKeySet.KEY_R_STAFF_ID));
        }

        // 构建可选未被增加过的成员
        for (Map<String, String> staff : srcStaffs) {
            if (!existMap.containsKey(staff.get(PmMapKeySet.KEY_R_STAFF_ID))) {
                retList.add(staff);
            }
        }

        return retList;
    }

}
