package com.nationrel.modules.project.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.google.common.collect.Maps;
import com.nationrel.modules.project.dto.PmTaskInfoDto;
import com.nationrel.modules.project.entity.PmTaskInfo;
import com.nationrel.modules.project.jar.dto.input.Rb0300220InitInput;
import com.nationrel.modules.project.jar.dto.output.Rb0300220InitOutput;
import com.nationrel.modules.project.jar.entity.PmProject;
import com.nationrel.modules.project.jar.entity.PmTask;
import com.nationrel.modules.project.jar.entity.PmTg;
import com.nationrel.modules.project.jar.entity.TaskPageModel;
import com.nationrel.modules.project.jar.mapper.PmProjectMapper;
import com.nationrel.modules.project.jar.mapper.PmTaskMapper;
import com.nationrel.modules.project.jar.mapper.PmTgMapper;
import com.nationrel.modules.project.jar.rb_common.common.constant.ReliaFlowConstants;
import com.nationrel.modules.project.jar.service.PmPercentStatService;
import com.nationrel.modules.project.jar.service.PmProjectService;
import com.nationrel.modules.project.jar.service.Rb0300220InitService;
import com.nationrel.modules.project.jar.util.DateUtils;
import com.nationrel.modules.project.mapper.PmTaskInfoMapper;
import com.nationrel.modules.project.req.PmProjectEditReq;
import com.nationrel.modules.project.req.PmTaskEditReq;
import com.nationrel.modules.project.req.PmTgEditReq;
import com.nationrel.modules.project.service.IPmTaskInfoService;
import org.apache.commons.lang3.ObjectUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.shiro.SecurityUtils;
import org.jeecg.common.system.vo.LoginUser;
import org.jeecg.config.i18n.MessageUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.util.CollectionUtils;

import java.math.BigDecimal;
import java.util.*;

/**
 * @Description: t_pm_tg
 * @Author: nationrel
 * @Date:   2024-10-23
 * @Version: V1.0
 */
@Service
public class PmTaskInfoServiceImpl extends ServiceImpl<PmTaskInfoMapper, PmTaskInfo> implements IPmTaskInfoService {

    @Autowired
    private PmTaskInfoMapper pmTaskInfoMapper;
    @Autowired
    private PmTgMapper pmTgMapper;
    @Autowired
    private PmTaskMapper pmTaskMapper;
    @Autowired
    private Rb0300220InitService rb0300220InitService;
    @Autowired
    private PmPercentStatService pmPercentStatService;
    @Autowired
    private PmProjectService pmProjectService;
    @Autowired
    private PmProjectMapper pmProjectMapper;

    @Override
    public IPage<PmTaskInfoDto> selectPmTaskInfoPage(Page page, String projectId) {
        Map<String, Integer> childMap = Maps.newHashMap();
        PmTaskInfoDto pmTaskInfoDto = pmTaskInfoMapper.selectPmProjectInfoById(projectId);
        pmTaskInfoDto.setStateName(MessageUtils.get(pmTaskInfoDto.getStateName()));
        pmTaskInfoDto.setWbs("0");
        IPage<PmTaskInfoDto> pmTaskInfoDtoIPage = pmTaskInfoMapper.selectPmTaskInfoList(page, projectId);

        if (!CollectionUtils.isEmpty(pmTaskInfoDtoIPage.getRecords())) {
            var ref = new Object() {
                BigDecimal percent = new BigDecimal("0");
            };
            pmTaskInfoDtoIPage.getRecords().forEach(item -> {
                item.setStateName(MessageUtils.get(item.getStateName()));
                item.setWbs(item.getTgSort() + "");
                item.setId(item.getTgId());
                Rb0300220InitInput input = new Rb0300220InitInput();
                Rb0300220InitOutput output = new Rb0300220InitOutput();
                input.setTgId(item.getTgId());
                input.setProjectId(item.getProjectId());
                try {
                    Rb0300220InitOutput children = rb0300220InitService.perform(input, output);
                    if (ObjectUtils.isNotEmpty(children) && !CollectionUtils.isEmpty(children.getTasks())) {
                        List<TaskPageModel> childTask = getChildTask(item.getTgId(), children.getTasks(), item.getWbs(), childMap);
                        item.setChildTask(childTask);
                        item.setChildrenCount(childMap.get(item.getTgId()) + childTask.size());
                        BigDecimal sum = children.getTasks().stream().filter(i -> ObjectUtils.isNotEmpty(i.getPercent())).map(TaskPageModel::getPercent).reduce(BigDecimal.ZERO, BigDecimal::add);
                        if (ObjectUtils.isNotEmpty(sum)) {
                            item.setPercent(sum.divide(new BigDecimal(children.getTasks().size())));
                            ref.percent = ref.percent.add(item.getPercent());
                        }
//                        item.setPercent();
//                        item.setChildTask(children.getTasks());
                        /*List<TaskPageModel> parent = children.getTasks().stream().filter(item -> item.getParentTaskId().equals(ReliaFlowConstants.TASK_FIRST_PARENT_ID)).toList();
                        if (!CollectionUtils.isEmpty(parent)) {
                            parent.forEach(it -> {
                                it.setChildTask(children.getTasks().stream().filter(child -> child.getParentTaskId().equals(it.getTaskId())).toList());
                            });
                        }*/

                    }
                } catch (Exception e) {
                    log.error("子任务查询异常", e);
                }
            });
            if (ObjectUtils.isNotEmpty(ref.percent)) {
                pmTaskInfoDto.setPercent(ref.percent.divide(new BigDecimal(pmTaskInfoDtoIPage.getRecords().size())));
            }
            pmTaskInfoDtoIPage.getRecords().add(0, pmTaskInfoDto);
        }

        return pmTaskInfoDtoIPage;
    }

    @Override
    public void updateTgInfo(PmTgEditReq pmtgEditReq) {
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        PmTg dbPmTg = pmTgMapper.selectByPrimaryKey(pmtgEditReq.getTgId());
        if (dbPmTg.getVersionNo().equals(pmtgEditReq.getVersionNo())) {
            if (StringUtils.isNotEmpty(pmtgEditReq.getTgName())) {
                dbPmTg.setTgName(pmtgEditReq.getTgName());
            }
            if (StringUtils.isNotEmpty(pmtgEditReq.getPlanStartTime())) {
                dbPmTg.setPlanStartTime(DateUtils.convertDate(pmtgEditReq.getPlanStartTime()));
            }
            if (StringUtils.isNotEmpty(pmtgEditReq.getPlanEndTime())) {
                dbPmTg.setPlanEndTime(DateUtils.convertDate(pmtgEditReq.getPlanEndTime()));
            }
            dbPmTg.setUpdateTime(new Date());
            dbPmTg.setUpdateUserId(sysUser.getUsername());
            dbPmTg.setUpdatePgmId("1");
            dbPmTg.setVersionNo(dbPmTg.getVersionNo()+1);
            pmTgMapper.updateByPrimaryKey(dbPmTg);
        } else {
            throw new RuntimeException("版本号不一致");
        }
    }

    @Override
    public void updateTaskInfo(PmTaskEditReq pmTask) {
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        PmTask dbPmTask = pmTaskMapper.selectByPrimaryKey(pmTask.getTaskId());
        if (dbPmTask.getVersionNo().equals(pmTask.getVersionNo())) {
            if (StringUtils.isNotEmpty(pmTask.getTaskName())) {
                dbPmTask.setTaskName(pmTask.getTaskName());
            }
            if (StringUtils.isNotEmpty(pmTask.getPlanStartTime())) {
                dbPmTask.setPlanStartTime(DateUtils.convertDate(pmTask.getPlanStartTime()));
            }
            if (StringUtils.isNotEmpty(pmTask.getPlanEndTime())) {
                dbPmTask.setPlanEndTime(DateUtils.convertDate(pmTask.getPlanEndTime()));
            }
            dbPmTask.setUpdateTime(new Date());
            dbPmTask.setUpdateUserId(sysUser.getUsername());
            dbPmTask.setUpdatePgmId("1");
            dbPmTask.setVersionNo(dbPmTask.getVersionNo()+1);
            pmTaskMapper.updateByPrimaryKey(dbPmTask);
        } else {
            throw new RuntimeException("版本号不一致");
        }
    }

    @Override
    public void updateProjectInfo(PmProjectEditReq pmProjectEditReq) throws Exception {

        PmProject pmProject = pmProjectMapper.selectByPrimaryKey(pmProjectEditReq.getProjectId());
        Date startTime = DateUtils.convertDate(pmProjectEditReq.getPlanStartTime());
        Date endTime = DateUtils.convertDate(pmProjectEditReq.getPlanEndTime());
        // 时间有变动，时间整合性检查
        if (DateUtils.isNotDateEquals(pmProject.getPlanStartTime(), startTime) ||
                DateUtils.isNotDateEquals(pmProject.getPlanEndTime(), endTime)) {
            pmProjectService.checkContainTimeOfTG(startTime, endTime, pmProjectEditReq.getProjectId());
        }
    }

    private List<TaskPageModel> getChildTask(String tgId, List<TaskPageModel> taskPageModels, String parentWbs, Map<String, Integer> childMap) {
        List<TaskPageModel> parent = taskPageModels.stream().filter(item -> item.getParentTaskId().equals(ReliaFlowConstants.TASK_FIRST_PARENT_ID)).toList();
        int index = 1;
        if (!childMap.containsKey(tgId)) {
            childMap.put(tgId, 0);
        }
        if (!CollectionUtils.isEmpty(parent)) {
            for (TaskPageModel it : parent) {
                int childCount = 0;
                it.setId(it.getTaskId());
                it.setStateName(MessageUtils.get(it.getStateName()));
                it.setWbs(parentWbs + "." + index++);
                List<TaskPageModel> list = taskPageModels.stream().filter(child -> child.getParentTaskId().equals(it.getTaskId())).toList();
                if (!CollectionUtils.isEmpty(list)) {
                    /*list.forEach(child -> {
                        child.setWbs(it.getWbs() + "." + child.getLeftNo());
                        child.setStateName(MessageUtils.get(child.getStateName()));
                    });*/
                    List<TaskPageModel> childTask = getChildTask(tgId, list, it.getWbs(), childMap);
                    it.setChildren(childTask);
                    it.setChildrenCount(childCount + childTask.size());
                    childMap.put(tgId, childMap.get(tgId) + childTask.size());
                }
            }
            return parent;
        } else {
            for (TaskPageModel it : taskPageModels) {
                int childCount = 0;
                it.setId(it.getTaskId());
                it.setStateName(MessageUtils.get(it.getStateName()));
                it.setWbs(parentWbs + "." + index++);
                List<TaskPageModel> list = taskPageModels.stream().filter(child -> child.getParentTaskId().equals(it.getTaskId())).toList();
                if (!CollectionUtils.isEmpty(list)) {
                    List<TaskPageModel> childTask = getChildTask(tgId, list, it.getWbs(), childMap);
                    it.setChildren(childTask);
                    it.setChildrenCount(childCount + childTask.size());
                    childMap.put(tgId, childMap.get(tgId) + childTask.size());
                }
            }
            return taskPageModels;
        }
    }
}
